pub trait InputDevice {
// Required method
fn poll(&mut self) -> Option<Event>;
}Expand description
Trait for input devices such as touchscreens or mice.
pub trait InputDevice {
// Required method
fn poll(&mut self) -> Option<Event>;
}Trait for input devices such as touchscreens or mice.